<?php

namespace EventPortal\Domain\Agenda\Models;

use Carbon\Carbon;
use EventPortal\Domain\Event\Models\Event;
use Illuminate\Database\Eloquent\Builder;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;

class Agenda extends Model
{
    /** @var array<string> */
    protected $guarded = [];

    /** @var array<string> */
    protected $casts = [
        'date' => 'date:Y-m-d',
    ];

    public function event(): BelongsTo
    {
        return $this->belongsTo(Event::class);
    }

    public function pathways(): HasMany
    {
        return $this->hasMany(Pathway::class);
    }

    public static function createForEvent(Event $event, Carbon $date): Agenda
    {
        return Agenda::create([
            'event_id' => $event->id,
            'date' => $date,
        ]);
    }

    public function scopeForEvent(Builder $query, Event $event): Builder
    {
        return $query->where('event_id', $event->id);
    }

    public function scopeForDate(Builder $query, string $date): Builder
    {
        return $query->whereDate('date', $date);
    }
}
