<?php

namespace EventPortal\Http\Controllers\Admin\Email;

use EventPortal\Domain\Email\Models\Email;
use EventPortal\Domain\Email\PreviewEmail;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Http\Controllers\Controller;
use EventPortal\Http\Requests\SendPreviewEmailRequest;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;

class EmailPreviewController extends Controller
{
    public function __construct()
    {
        $this->middleware('check-permission:email.show');
    }

    /**
     * @return mixed
     */
    // phpcs:disable Generic.CodeAnalysis.UnusedFunctionParameter
    public function show(Request $request, Event $event, Email $email)
    {
        // phpcs:enable
        $previewEmail = new PreviewEmail($email);

        if ($request->has('plain-text')) {
            return $previewEmail->renderPlainText();
        }

        return $previewEmail->render();
    }

    public function store(SendPreviewEmailRequest $request, Event $event, Email $email): RedirectResponse
    {
        collect($request->recipients)->each(static function ($recipient) use ($email): void {
            Mail::to($recipient)->send(new PreviewEmail($email));
        });
        toast()->success(trans('email.preview.sent'));

        return redirect()->route('admin.email.index', [
            'event' => $event->id,
        ]);
    }
}
